@@ -1,6 +1,7 @@
 """
 Main CLI entrypoint.
 """
+
 import sys
 
 
@@ -9,8 +10,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.RecycleBin 1.26.0\nVersion:         1.26.0.post1\nBuilder"
-        " version: 7.11.10\nDocs:           "
+        "Type annotations for boto3.RecycleBin 1.33.6\nVersion:         1.33.6\nBuilder version:"
+        " 7.21.0\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rbin//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rbin.html#RecycleBin\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +23,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.26.0.post1")
+    print("1.33.6")
 
 
 def main() -> None:
