@@ -13,25 +13,29 @@ Usage::
     client: RecycleBinClient = session.client("rbin")
     ```
 """
+
 import sys
 from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import ResourceTypeType
+from .literals import LockStateType, ResourceTypeType
 from .paginator import ListRulesPaginator
 from .type_defs import (
     CreateRuleResponseTypeDef,
     GetRuleResponseTypeDef,
     ListRulesResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    LockConfigurationTypeDef,
+    LockRuleResponseTypeDef,
     ResourceTagTypeDef,
     RetentionPeriodTypeDef,
     TagTypeDef,
+    UnlockRuleResponseTypeDef,
     UpdateRuleResponseTypeDef,
 )
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -40,7 +44,7 @@ else:
 __all__ = ("RecycleBinClient",)
 
 
-class BotocoreClientError(BaseException):
+class BotocoreClientError(Exception):
     MSG_TEMPLATE: str
 
     def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
@@ -50,6 +54,7 @@ class BotocoreClientError(BaseException):
 
 class Exceptions:
     ClientError: Type[BotocoreClientError]
+    ConflictException: Type[BotocoreClientError]
     InternalServerException: Type[BotocoreClientError]
     ResourceNotFoundException: Type[BotocoreClientError]
     ServiceQuotaExceededException: Type[BotocoreClientError]
@@ -96,7 +101,8 @@ class RecycleBinClient(BaseClient):
         ResourceType: ResourceTypeType,
         Description: str = ...,
         Tags: Sequence[TagTypeDef] = ...,
-        ResourceTags: Sequence[ResourceTagTypeDef] = ...
+        ResourceTags: Sequence[ResourceTagTypeDef] = ...,
+        LockConfiguration: LockConfigurationTypeDef = ...
     ) -> CreateRuleResponseTypeDef:
         """
         Creates a Recycle Bin retention rule.
@@ -141,7 +147,8 @@ class RecycleBinClient(BaseClient):
         ResourceType: ResourceTypeType,
         MaxResults: int = ...,
         NextToken: str = ...,
-        ResourceTags: Sequence[ResourceTagTypeDef] = ...
+        ResourceTags: Sequence[ResourceTagTypeDef] = ...,
+        LockState: LockStateType = ...
     ) -> ListRulesResponseTypeDef:
         """
         Lists the Recycle Bin retention rules in the Region.
@@ -158,6 +165,16 @@ class RecycleBinClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rbin/client/#list_tags_for_resource)
         """
 
+    def lock_rule(
+        self, *, Identifier: str, LockConfiguration: LockConfigurationTypeDef
+    ) -> LockRuleResponseTypeDef:
+        """
+        Locks a retention rule.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rbin.html#RecycleBin.Client.lock_rule)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rbin/client/#lock_rule)
+        """
+
     def tag_resource(self, *, ResourceArn: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Assigns tags to the specified retention rule.
@@ -166,6 +183,14 @@ class RecycleBinClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rbin/client/#tag_resource)
         """
 
+    def unlock_rule(self, *, Identifier: str) -> UnlockRuleResponseTypeDef:
+        """
+        Unlocks a retention rule.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/rbin.html#RecycleBin.Client.unlock_rule)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_rbin/client/#unlock_rule)
+        """
+
     def untag_resource(self, *, ResourceArn: str, TagKeys: Sequence[str]) -> Dict[str, Any]:
         """
         Unassigns a tag from a retention rule.
