@@ -19,11 +19,12 @@ Usage::
     list_rules_paginator: ListRulesPaginator = client.get_paginator("list_rules")
     ```
 """
+
 from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator, Paginator
 
-from .literals import ResourceTypeType
+from .literals import LockStateType, ResourceTypeType
 from .type_defs import ListRulesResponseTypeDef, PaginatorConfigTypeDef, ResourceTagTypeDef
 
 __all__ = ("ListRulesPaginator",)
@@ -50,6 +51,7 @@ class ListRulesPaginator(Paginator):
         *,
         ResourceType: ResourceTypeType,
         ResourceTags: Sequence[ResourceTagTypeDef] = ...,
+        LockState: LockStateType = ...,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRulesResponseTypeDef]:
         """
