@@ -8,19 +8,25 @@ Usage::
     ```python
     from mypy_boto3_rbin.type_defs import ResourceTagTypeDef
 
-    data: ResourceTagTypeDef = {...}
+    data: ResourceTagTypeDef = ...
     ```
 """
+
 import sys
+from datetime import datetime
 from typing import Dict, List, Sequence
 
-from .literals import ResourceTypeType, RuleStatusType
+from .literals import LockStateType, ResourceTypeType, RuleStatusType
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
+    from typing import NotRequired
+else:
+    from typing_extensions import NotRequired
+if sys.version_info >= (3, 12):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -35,39 +41,33 @@ __all__ = (
     "GetRuleRequestRequestTypeDef",
     "PaginatorConfigTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
+    "UnlockDelayTypeDef",
+    "UnlockRuleRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "ListRulesRequestRequestTypeDef",
     "RuleSummaryTypeDef",
     "UpdateRuleRequestRequestTypeDef",
-    "CreateRuleRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
-    "CreateRuleResponseTypeDef",
-    "GetRuleResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "UpdateRuleResponseTypeDef",
     "ListRulesRequestListRulesPaginateTypeDef",
+    "LockConfigurationTypeDef",
     "ListRulesResponseTypeDef",
+    "CreateRuleRequestRequestTypeDef",
+    "CreateRuleResponseTypeDef",
+    "GetRuleResponseTypeDef",
+    "LockRuleRequestRequestTypeDef",
+    "LockRuleResponseTypeDef",
+    "UnlockRuleResponseTypeDef",
 )
 
-_RequiredResourceTagTypeDef = TypedDict(
-    "_RequiredResourceTagTypeDef",
+ResourceTagTypeDef = TypedDict(
+    "ResourceTagTypeDef",
     {
         "ResourceTagKey": str,
+        "ResourceTagValue": NotRequired[str],
     },
 )
-_OptionalResourceTagTypeDef = TypedDict(
-    "_OptionalResourceTagTypeDef",
-    {
-        "ResourceTagValue": str,
-    },
-    total=False,
-)
-
-
-class ResourceTagTypeDef(_RequiredResourceTagTypeDef, _OptionalResourceTagTypeDef):
-    pass
-
-
 RetentionPeriodTypeDef = TypedDict(
     "RetentionPeriodTypeDef",
     {
@@ -75,7 +75,6 @@ RetentionPeriodTypeDef = TypedDict(
         "RetentionPeriodUnit": Literal["DAYS"],
     },
 )
-
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -83,7 +82,6 @@ TagTypeDef = TypedDict(
         "Value": str,
     },
 )
-
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -94,38 +92,45 @@ ResponseMetadataTypeDef = TypedDict(
         "RetryAttempts": int,
     },
 )
-
 DeleteRuleRequestRequestTypeDef = TypedDict(
     "DeleteRuleRequestRequestTypeDef",
     {
         "Identifier": str,
     },
 )
-
 GetRuleRequestRequestTypeDef = TypedDict(
     "GetRuleRequestRequestTypeDef",
     {
         "Identifier": str,
     },
 )
-
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
-
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
     },
 )
-
+UnlockDelayTypeDef = TypedDict(
+    "UnlockDelayTypeDef",
+    {
+        "UnlockDelayValue": int,
+        "UnlockDelayUnit": Literal["DAYS"],
+    },
+)
+UnlockRuleRequestRequestTypeDef = TypedDict(
+    "UnlockRuleRequestRequestTypeDef",
+    {
+        "Identifier": str,
+    },
+)
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -133,88 +138,36 @@ UntagResourceRequestRequestTypeDef = TypedDict(
         "TagKeys": Sequence[str],
     },
 )
-
-_RequiredListRulesRequestRequestTypeDef = TypedDict(
-    "_RequiredListRulesRequestRequestTypeDef",
+ListRulesRequestRequestTypeDef = TypedDict(
+    "ListRulesRequestRequestTypeDef",
     {
         "ResourceType": ResourceTypeType,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
+        "ResourceTags": NotRequired[Sequence[ResourceTagTypeDef]],
+        "LockState": NotRequired[LockStateType],
     },
 )
-_OptionalListRulesRequestRequestTypeDef = TypedDict(
-    "_OptionalListRulesRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-        "ResourceTags": Sequence[ResourceTagTypeDef],
-    },
-    total=False,
-)
-
-
-class ListRulesRequestRequestTypeDef(
-    _RequiredListRulesRequestRequestTypeDef, _OptionalListRulesRequestRequestTypeDef
-):
-    pass
-
-
 RuleSummaryTypeDef = TypedDict(
     "RuleSummaryTypeDef",
     {
-        "Identifier": str,
-        "Description": str,
-        "RetentionPeriod": RetentionPeriodTypeDef,
+        "Identifier": NotRequired[str],
+        "Description": NotRequired[str],
+        "RetentionPeriod": NotRequired[RetentionPeriodTypeDef],
+        "LockState": NotRequired[LockStateType],
+        "RuleArn": NotRequired[str],
     },
-    total=False,
 )
-
-_RequiredUpdateRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateRuleRequestRequestTypeDef",
+UpdateRuleRequestRequestTypeDef = TypedDict(
+    "UpdateRuleRequestRequestTypeDef",
     {
         "Identifier": str,
+        "RetentionPeriod": NotRequired[RetentionPeriodTypeDef],
+        "Description": NotRequired[str],
+        "ResourceType": NotRequired[ResourceTypeType],
+        "ResourceTags": NotRequired[Sequence[ResourceTagTypeDef]],
     },
 )
-_OptionalUpdateRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateRuleRequestRequestTypeDef",
-    {
-        "RetentionPeriod": RetentionPeriodTypeDef,
-        "Description": str,
-        "ResourceType": ResourceTypeType,
-        "ResourceTags": Sequence[ResourceTagTypeDef],
-    },
-    total=False,
-)
-
-
-class UpdateRuleRequestRequestTypeDef(
-    _RequiredUpdateRuleRequestRequestTypeDef, _OptionalUpdateRuleRequestRequestTypeDef
-):
-    pass
-
-
-_RequiredCreateRuleRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateRuleRequestRequestTypeDef",
-    {
-        "RetentionPeriod": RetentionPeriodTypeDef,
-        "ResourceType": ResourceTypeType,
-    },
-)
-_OptionalCreateRuleRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateRuleRequestRequestTypeDef",
-    {
-        "Description": str,
-        "Tags": Sequence[TagTypeDef],
-        "ResourceTags": Sequence[ResourceTagTypeDef],
-    },
-    total=False,
-)
-
-
-class CreateRuleRequestRequestTypeDef(
-    _RequiredCreateRuleRequestRequestTypeDef, _OptionalCreateRuleRequestRequestTypeDef
-):
-    pass
-
-
 TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
@@ -222,7 +175,62 @@ TagResourceRequestRequestTypeDef = TypedDict(
         "Tags": Sequence[TagTypeDef],
     },
 )
-
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+UpdateRuleResponseTypeDef = TypedDict(
+    "UpdateRuleResponseTypeDef",
+    {
+        "Identifier": str,
+        "RetentionPeriod": RetentionPeriodTypeDef,
+        "Description": str,
+        "ResourceType": ResourceTypeType,
+        "ResourceTags": List[ResourceTagTypeDef],
+        "Status": RuleStatusType,
+        "LockState": LockStateType,
+        "LockEndTime": datetime,
+        "RuleArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+ListRulesRequestListRulesPaginateTypeDef = TypedDict(
+    "ListRulesRequestListRulesPaginateTypeDef",
+    {
+        "ResourceType": ResourceTypeType,
+        "ResourceTags": NotRequired[Sequence[ResourceTagTypeDef]],
+        "LockState": NotRequired[LockStateType],
+        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
+    },
+)
+LockConfigurationTypeDef = TypedDict(
+    "LockConfigurationTypeDef",
+    {
+        "UnlockDelay": UnlockDelayTypeDef,
+    },
+)
+ListRulesResponseTypeDef = TypedDict(
+    "ListRulesResponseTypeDef",
+    {
+        "Rules": List[RuleSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+CreateRuleRequestRequestTypeDef = TypedDict(
+    "CreateRuleRequestRequestTypeDef",
+    {
+        "RetentionPeriod": RetentionPeriodTypeDef,
+        "ResourceType": ResourceTypeType,
+        "Description": NotRequired[str],
+        "Tags": NotRequired[Sequence[TagTypeDef]],
+        "ResourceTags": NotRequired[Sequence[ResourceTagTypeDef]],
+        "LockConfiguration": NotRequired[LockConfigurationTypeDef],
+    },
+)
 CreateRuleResponseTypeDef = TypedDict(
     "CreateRuleResponseTypeDef",
     {
@@ -233,10 +241,12 @@ CreateRuleResponseTypeDef = TypedDict(
         "ResourceType": ResourceTypeType,
         "ResourceTags": List[ResourceTagTypeDef],
         "Status": RuleStatusType,
+        "LockConfiguration": LockConfigurationTypeDef,
+        "LockState": LockStateType,
+        "RuleArn": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
-
 GetRuleResponseTypeDef = TypedDict(
     "GetRuleResponseTypeDef",
     {
@@ -246,59 +256,48 @@ GetRuleResponseTypeDef = TypedDict(
         "RetentionPeriod": RetentionPeriodTypeDef,
         "ResourceTags": List[ResourceTagTypeDef],
         "Status": RuleStatusType,
+        "LockConfiguration": LockConfigurationTypeDef,
+        "LockState": LockStateType,
+        "LockEndTime": datetime,
+        "RuleArn": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
+LockRuleRequestRequestTypeDef = TypedDict(
+    "LockRuleRequestRequestTypeDef",
     {
-        "Tags": List[TagTypeDef],
-        "ResponseMetadata": ResponseMetadataTypeDef,
+        "Identifier": str,
+        "LockConfiguration": LockConfigurationTypeDef,
     },
 )
-
-UpdateRuleResponseTypeDef = TypedDict(
-    "UpdateRuleResponseTypeDef",
+LockRuleResponseTypeDef = TypedDict(
+    "LockRuleResponseTypeDef",
     {
         "Identifier": str,
-        "RetentionPeriod": RetentionPeriodTypeDef,
         "Description": str,
         "ResourceType": ResourceTypeType,
+        "RetentionPeriod": RetentionPeriodTypeDef,
         "ResourceTags": List[ResourceTagTypeDef],
         "Status": RuleStatusType,
+        "LockConfiguration": LockConfigurationTypeDef,
+        "LockState": LockStateType,
+        "RuleArn": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
-
-_RequiredListRulesRequestListRulesPaginateTypeDef = TypedDict(
-    "_RequiredListRulesRequestListRulesPaginateTypeDef",
+UnlockRuleResponseTypeDef = TypedDict(
+    "UnlockRuleResponseTypeDef",
     {
+        "Identifier": str,
+        "Description": str,
         "ResourceType": ResourceTypeType,
-    },
-)
-_OptionalListRulesRequestListRulesPaginateTypeDef = TypedDict(
-    "_OptionalListRulesRequestListRulesPaginateTypeDef",
-    {
-        "ResourceTags": Sequence[ResourceTagTypeDef],
-        "PaginationConfig": PaginatorConfigTypeDef,
-    },
-    total=False,
-)
-
-
-class ListRulesRequestListRulesPaginateTypeDef(
-    _RequiredListRulesRequestListRulesPaginateTypeDef,
-    _OptionalListRulesRequestListRulesPaginateTypeDef,
-):
-    pass
-
-
-ListRulesResponseTypeDef = TypedDict(
-    "ListRulesResponseTypeDef",
-    {
-        "Rules": List[RuleSummaryTypeDef],
-        "NextToken": str,
+        "RetentionPeriod": RetentionPeriodTypeDef,
+        "ResourceTags": List[ResourceTagTypeDef],
+        "Status": RuleStatusType,
+        "LockConfiguration": LockConfigurationTypeDef,
+        "LockState": LockStateType,
+        "LockEndTime": datetime,
+        "RuleArn": str,
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
